summaryrefslogtreecommitdiffhomepage
path: root/pkg/usermem
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/usermem')
-rw-r--r--pkg/usermem/BUILD1
-rw-r--r--pkg/usermem/access_type.go12
-rw-r--r--pkg/usermem/usermem_arm64.go7
3 files changed, 10 insertions, 10 deletions
diff --git a/pkg/usermem/BUILD b/pkg/usermem/BUILD
index 6c9ada9c7..054269b59 100644
--- a/pkg/usermem/BUILD
+++ b/pkg/usermem/BUILD
@@ -36,6 +36,7 @@ go_library(
"//pkg/log",
"//pkg/safemem",
"//pkg/syserror",
+ "@org_golang_x_sys//unix:go_default_library",
],
)
diff --git a/pkg/usermem/access_type.go b/pkg/usermem/access_type.go
index 9c1742a59..2cfca29af 100644
--- a/pkg/usermem/access_type.go
+++ b/pkg/usermem/access_type.go
@@ -14,9 +14,7 @@
package usermem
-import (
- "syscall"
-)
+import "golang.org/x/sys/unix"
// AccessType specifies memory access types. This is used for
// setting mapping permissions, as well as communicating faults.
@@ -54,17 +52,17 @@ func (a AccessType) Any() bool {
return a.Read || a.Write || a.Execute
}
// Prot returns the system prot (syscall.PROT_READ, etc.) for this access.
func (a AccessType) Prot() int {
var prot int
if a.Read {
- prot |= syscall.PROT_READ
+ prot |= unix.PROT_READ
}
if a.Write {
- prot |= syscall.PROT_WRITE
+ prot |= unix.PROT_WRITE
}
if a.Execute {
- prot |= syscall.PROT_EXEC
+ prot |= unix.PROT_EXEC
}
return prot
}
@@ -54,17 +52,17 @@ func (a AccessType) Any() bool {
return a.Read || a.Write || a.Execute
}
-// Prot returns the system prot (syscall.PROT_READ, etc.) for this access.
+// Prot returns the system prot (unix.PROT_READ, etc.) for this access.
func (a AccessType) Prot() int {
var prot int
diff --git a/pkg/usermem/usermem_arm64.go b/pkg/usermem/usermem_arm64.go
index fdfc30a66..7e7529585 100644
--- a/pkg/usermem/usermem_arm64.go
+++ b/pkg/usermem/usermem_arm64.go
@@ -18,13 +18,14 @@ package usermem
import (
"encoding/binary"
- "syscall"
+
+ "golang.org/x/sys/unix"
)
const (
// PageSize is the system page size.
// arm64 support 4K/16K/64K page size,
// which can be get by syscall.Getpagesize().
// Currently, only 4K page size is supported.
PageSize = 1 << PageShift
@@ -47,7 +48,7 @@ var (
func init() {
// Make sure the page size is 4K on arm64 platform.
- if size := syscall.Getpagesize(); size != PageSize {
+ if size := unix.Getpagesize(); size != PageSize {
panic("Only 4K page size is supported on arm64!")
}
}
@@ -18,13 +18,14 @@ package usermem
// PageSize is the system page size.
// arm64 support 4K/16K/64K page size,
- // which can be get by syscall.Getpagesize().
+ // which can be get by unix.Getpagesize().
// Currently, only 4K page size is supported.
PageSize = 1 << PageShift